# esi-shakelib

## Introduction

This repository contains a utility package for general ShakeMap functions that may be of use to other programs.
Included are:

- IMC and IMT conversions
- Cross correlation functions
- Directivity functions
- GMICE functions
- Specialized NGA-East GMPEs for small magnitude earthquakes
- Contour and rupture plotting functions
- Misc. other functions

See the code for documentation.

## Installation

The package is available on PyPI. Install with pip:

    pip install esi-shakelib
